import { Dialog } from "@jupyterlab/apputils";
import { JSONObject, JSONValue } from "@phosphor/coreutils";
import { Widget } from '@lumino/widgets';
import { DocumentRegistry } from "@jupyterlab/docregistry";
import { INotebookModel, NotebookPanel } from "@jupyterlab/notebook";
import { JupyterFrontEnd } from "@jupyterlab/application";
import { IDisposable } from "@phosphor/disposable";
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
/**
 * Details about notebook submission configuration, including
 * details about the remote platform and any other
 * user details required to access/start the job
 */
export interface ISubmitNotebookConfiguration extends JSONObject {
    dependencies: string;
    vm_label: string;
    pipeline_name: string;
    schedule_express: string;
    execute_now: boolean;
    env: {
        [index: string]: string;
    };
}
/**
 * Details about notebook submission task, includes the submission
 * configuration plus the notebook contents that is being submitted
 */
export interface ISubmitNotebookTask extends ISubmitNotebookConfiguration {
    kernelspec: string;
    notebook_name: string;
    notebook_full_path: string;
    root_path: string;
    notebook: JSONValue;
}
/**
 * Submit notebook button extension
 *  - Attach button to notebook toolbar and launch a dialog requesting
 *  information about the remote location to where submit the notebook
 *  for execution
 */
export declare class SubmitNotebookButtonExtension implements DocumentRegistry.IWidgetExtension<NotebookPanel, INotebookModel> {
    private panel;
    private context;
    constructor(app: JupyterFrontEnd, browserFactory: IFileBrowserFactory);
    readonly app: JupyterFrontEnd;
    browserFactory: IFileBrowserFactory;
    showWidget: () => void;
    createNew(panel: NotebookPanel, context: DocumentRegistry.IContext<INotebookModel>): IDisposable;
}
/**
 * Submit notebook dialog extension
 * - Request information about the remote location to where submit the
 * notebook for execution
 */
export declare class SubmitNotebook extends Widget implements Dialog.IBodyWidget<ISubmitNotebookConfiguration> {
    private _htmlDialogElement;
    _envVars: {
        [index: string]: string;
    };
    _env_key_list: string[];
    _notebookName: string;
    browserFactory: IFileBrowserFactory;
    constructor(envVars: {}, notebookName: string, browserFactory: IFileBrowserFactory);
    /**
     * Render the dialog widget used to gather configuration information
     * required to submit/run the notebook remotely
     */
    renderHtml(notebook_name: string): HTMLDivElement;
    getEnvHtml(): string;
    getValue(): ISubmitNotebookConfiguration;
}
