/**
 * A utilities class for static functions.
 */
export default class Utils {
    /**
     * Takes in a notebook and finds all env vars accessed in it.
     * @param notebookStr Raw notebook JSON in string format
     * @returns A string array of the env vars accessed in the given notebook
     */
    static getEnvVars(notebookStr) {
        // let envVars: string[] = [];
        let env_dict = {};
        // let env_list: string[] = [];
        // let result_dict = {};
        let firstParameterCellFound = false;
        let notebook = JSON.parse(notebookStr);
        console.log('notebookStr: ' + notebookStr);
        // let match_regex = /os\.(?:environ(?:\["([^"]+)|\['([^']+)|\.get\("([^"]+)|\.get\('([^']+))|getenv\("([^"]+)|getenv\('([^']+))/;
        for (let cell of notebook['cells']) {
            if (cell['cell_type'] == 'code') {
                if (!firstParameterCellFound && cell.metadata.tags && cell.metadata.tags.includes('parameters')) {
                    firstParameterCellFound = true;
                    let regex = /(?=["'])(?:"[^"\\]*(?:\\[\s\S][^"\\]*)*"|'[^'\\]*(?:\\[\s\S][^'\\]*)*')|(#.*$)/gm;
                    let quoteRegex = /^["|'](.*)["|']$/g;
                    let parameterCode = cell.source.replace(regex, function (m, group1) {
                        if (group1 == null)
                            return m;
                        else
                            return "";
                    });
                    let lineArray = parameterCode.split(/\r?\n/);
                    for (let i = 0; i < lineArray.length; i++) {
                        let line = lineArray[i].trim();
                        if (line !== "") {
                            let paramLine = lineArray[i].split("=");
                            if (paramLine.length == 2) {
                                let key = paramLine[0].trim();
                                let value = paramLine[1].trim().replace(quoteRegex, '$1');
                                env_dict[key] = value;
                            }
                        }
                    }
                }
            }
        }
        return env_dict;
    }
    /**
     * Splits code string on new lines and matches each line on the given regex.
     * @param code Multi-line string to match on
     * @param regex Match regex to run on each line of code
     * @returns A 2d string array containing an array of the matched array results
     */
    static findInCode(code, regex) {
        let matched = [];
        let codeLines = code.split(/\r?\n/);
        for (let codeLine of codeLines) {
            let match = codeLine.match(regex);
            if (match) {
                matched.push(match);
            }
        }
        return matched;
    }
}
